@@ -1,18 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "mboximportkernel.h"
 
-#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
-#include <MailCommon/FolderCollectionMonitor>
 #include <AkonadiCore/session.h>
-#include <entitytreemodel.h>
-#include <entitymimetypefiltermodel.h>
-#include <changerecorder.h>
+#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
 #include <KSharedConfig>
+#include <MailCommon/FolderCollectionMonitor>
+#include <changerecorder.h>
+#include <entitymimetypefiltermodel.h>
+#include <entitytreemodel.h>
 
 MBoxImporterKernel::MBoxImporterKernel(QObject *parent)
     : QObject(parent)
@@ -104,11 +104,11 @@ Akonadi::Collection::Id MBoxImporterKernel::lastSelectedFolder()
 
 void MBoxImporterKernel::setLastSelectedFolder(Akonadi::Collection::Id col)
 {
-    Q_UNUSED(col);
+    Q_UNUSED(col)
 }
 
 void MBoxImporterKernel::expunge(Akonadi::Collection::Id col, bool sync)
 {
-    Q_UNUSED(col);
-    Q_UNUSED(sync);
+    Q_UNUSED(col)
+    Q_UNUSED(sync)
 }
